==> AsposeCellsCloud-CellsApi-25.9.tar.gz: AsposeCellsCloud-CellsApi-25.9/docs/model/ChartFrame.md <==
# AsposeCellsCloud::Object::ChartFrame 

## Load the model package
```perl
use AsposeCellsCloud::Object::ChartFrame;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Area** | **Area** | Gets the area.  |
**AutoScaleFont** | **boolean** | True if the text in the object changes font size when the object size changes. The default value is True.  |
**BackgroundMode** | **string** | Gets and sets the display mode of the background  |
**Border** | **Line** | Gets the border.  |
**Font** | **Font** | Gets a  object of the specified ChartFrame object.  |
**IsAutomaticSize** | **boolean** | Indicates whether the chart frame is automatic sized.  |
**IsInnerMode** | **boolean** | Indicates whether the size of the plot area size includes the tick marks, and the axis labels.            False specifies that the size shall determine the size of the plot area, the tick marks, and the axis labels.  |
**Shadow** | **boolean** | True if the frame has a shadow.  |
**Width** | **int** | Gets or sets the width of frame in units of 1/4000 of the chart area.  |
**Height** | **int** | Gets or sets the height of frame in units of 1/4000 of the chart area.  |
**X** | **int** | Gets or sets the x coordinate of the upper left corner in units of 1/4000 of the chart area.  |
**Y** | **int** | Gets or sets the y coordinate of the upper left corner in units of 1/4000 of the chart area.  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/ChartFrame.md <==
# AsposeCellsCloud::Object::ChartFrame 

## Load the model package
```perl
use AsposeCellsCloud::Object::ChartFrame;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Area** | **Area** | Gets the area.  |
**AutoScaleFont** | **boolean** | True if the text in the object changes font size when the object size changes. The default value is True.  |
**BackgroundMode** | **string** | Gets and sets the display mode of the background  |
**Border** | **Line** | Gets the border.  |
**Font** | **Font** | Gets a  object of the specified ChartFrame object.  |
**IsAutomaticSize** | **boolean** | Indicates whether the chart frame is automatic sized.  |
**IsInnerMode** | **boolean** | Indicates whether the size of the plot area size includes the tick marks, and the axis labels.            False specifies that the size shall determine the size of the plot area, the tick marks, and the axis labels.  |
**Shadow** | **boolean** | True if the frame has a shadow.  |
**Width** | **int** | Gets or sets the width of frame in units of 1/4000 of the chart area.  |
**Height** | **int** | Gets or sets the height of frame in units of 1/4000 of the chart area.  |
**X** | **int** | Gets or sets the x coordinate of the upper left corner in units of 1/4000 of the chart area.  |
**Y** | **int** | Gets or sets the y coordinate of the upper left corner in units of 1/4000 of the chart area.  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
